@@ -36,7 +36,6 @@ pub async fn new(conn: &DatabaseConnection) -> Result<ExecResult> {
 ///  删除策略
 pub async fn remove_policy(conn: &DatabaseConnection, pt: &str, rule: Vec<String>) -> Result<bool> {
     let rule = normalize_casbin_rule(rule, 0);
-    // let d =
     Entity::delete_many()
         .filter(Column::Ptype.eq(pt))
         .filter(Column::V0.eq((&rule[0]).clone()))
@@ -84,87 +83,86 @@ pub async fn remove_filtered_policy(
     field_index: usize,
     field_values: Vec<String>,
 ) -> Result<bool> {
-    let field_values = normalize_casbin_rule(field_values, field_index);
-    // let for_delete =
+    let field_values_x = normalize_casbin_rule(field_values, field_index);
+    let mut d = Entity::delete_many().filter(Column::Ptype.eq(pt));
     if field_index == 5 {
-        Entity::delete_many()
-            .filter(
-                Condition::all()
-                    .add(Column::Ptype.eq(pt))
-                    .add(Column::V5.eq((field_values[5]).clone())),
-            )
-            .exec(conn)
-            .await
-            .map_err(|err| CasbinError::from(AdapterError(Box::new(Error::DbErr(err)))))?;
+        if !field_values_x[0].is_empty() {
+            d = d.filter(Column::V5.eq(field_values_x[0].clone()));
+        }
     } else if field_index == 4 {
-        Entity::delete_many()
-            .filter(
-                Condition::all()
-                    .add(Column::Ptype.eq(pt))
-                    .add(Column::V4.eq((field_values[4]).clone()))
-                    .add(Column::V5.eq((field_values[5]).clone())),
-            )
-            .exec(conn)
-            .await
-            .map_err(|err| CasbinError::from(AdapterError(Box::new(Error::DbErr(err)))))?;
+        if !field_values_x[0].is_empty() {
+            d = d.filter(Column::V4.eq(field_values_x[0].clone()));
+        }
+        if !field_values_x[1].is_empty() {
+            d = d.filter(Column::V5.eq(field_values_x[1].clone()));
+        }
     } else if field_index == 3 {
-        Entity::delete_many()
-            .filter(
-                Condition::all()
-                    .add(Column::Ptype.eq(pt))
-                    .add(Column::V3.eq((field_values[3]).clone()))
-                    .add(Column::V4.eq((field_values[4]).clone()))
-                    .add(Column::V5.eq((field_values[5]).clone())),
-            )
-            .exec(conn)
-            .await
-            .map_err(|err| CasbinError::from(AdapterError(Box::new(Error::DbErr(err)))))?;
+        if !field_values_x[0].is_empty() {
+            d = d.filter(Column::V3.eq(field_values_x[0].clone()))
+        }
+        if !field_values_x[1].is_empty() {
+            d = d.filter(Column::V4.eq(field_values_x[1].clone()));
+        }
+        if !field_values_x[2].is_empty() {
+            d = d.filter(Column::V5.eq(field_values_x[2].clone()))
+        }
     } else if field_index == 2 {
-        Entity::delete_many()
-            .filter(
-                Condition::all()
-                    .add(Column::Ptype.eq(pt))
-                    .add(Column::V2.eq((field_values[2]).clone()))
-                    .add(Column::V3.eq((field_values[3]).clone()))
-                    .add(Column::V4.eq((field_values[4]).clone()))
-                    .add(Column::V5.eq((field_values[5]).clone())),
-            )
-            .exec(conn)
-            .await
-            .map_err(|err| CasbinError::from(AdapterError(Box::new(Error::DbErr(err)))))?;
+        if !field_values_x[0].is_empty() {
+            d = d.filter(Column::V2.eq(field_values_x[0].clone()));
+        }
+        if !field_values_x[1].is_empty() {
+            d = d.filter(Column::V3.eq(field_values_x[1].clone()));
+        }
+        if !field_values_x[2].is_empty() {
+            d = d.filter(Column::V4.eq(field_values_x[2].clone()));
+        }
+        if !field_values_x[3].is_empty() {
+            d = d.filter(Column::V5.eq(field_values_x[3].clone()));
+        }
     } else if field_index == 1 {
-        Entity::delete_many()
-            .filter(
-                Condition::all()
-                    .add(Column::Ptype.eq(pt))
-                    .add(Column::V1.eq((field_values[1]).clone()))
-                    .add(Column::V2.eq((field_values[2]).clone()))
-                    .add(Column::V3.eq((field_values[3]).clone()))
-                    .add(Column::V4.eq((field_values[4]).clone()))
-                    .add(Column::V5.eq((field_values[5]).clone())),
-            )
-            .exec(conn)
-            .await
-            .map_err(|err| CasbinError::from(AdapterError(Box::new(Error::DbErr(err)))))?;
+        if !field_values_x[0].is_empty() {
+            d = d.filter(Column::V1.eq(field_values_x[0].clone()));
+        }
+        if !field_values_x[1].is_empty() {
+            d = d.filter(Column::V2.eq(field_values_x[1].clone()));
+        }
+        if !field_values_x[2].is_empty() {
+            d = d.filter(Column::V3.eq(field_values_x[2].clone()));
+        }
+        if !field_values_x[3].is_empty() {
+            d = d.filter(Column::V4.eq(field_values_x[3].clone()));
+        }
+        if !field_values_x[4].is_empty() {
+            d = d.filter(Column::V5.eq(field_values_x[4].clone()));
+        }
     } else {
-        Entity::delete_many()
-            .filter(
-                Condition::all()
-                    .add(Column::Ptype.eq(pt))
-                    .add(Column::V0.eq((field_values[0]).clone()))
-                    .add(Column::V1.eq((field_values[1]).clone()))
-                    .add(Column::V2.eq((field_values[2]).clone()))
-                    .add(Column::V3.eq((field_values[3]).clone()))
-                    .add(Column::V4.eq((field_values[4]).clone()))
-                    .add(Column::V5.eq((field_values[5]).clone())),
-            )
-            .exec(conn)
-            .await
-            .map_err(|err| CasbinError::from(AdapterError(Box::new(Error::DbErr(err)))))?;
+        if !field_values_x[0].is_empty() {
+            d = d.filter(Column::V0.eq(field_values_x[0].clone()));
+        }
+        if !field_values_x[1].is_empty() {
+            d = d.filter(Column::V1.eq(field_values_x[1].clone()));
+        }
+        if !field_values_x[2].is_empty() {
+            d = d.filter(Column::V2.eq(field_values_x[2].clone()));
+        }
+        if !field_values_x[3].is_empty() {
+            d = d.filter(Column::V3.eq(field_values_x[3].clone()));
+        }
+        if !field_values_x[4].is_empty() {
+            d = d.filter(Column::V4.eq(field_values_x[4].clone()));
+        }
+        if !field_values_x[5].is_empty() {
+            d = d.filter(Column::V5.eq(field_values_x[5].clone()));
+        }
     };
+    //  执行删除
+    d.exec(conn)
+        .await
+        .map_err(|err| CasbinError::from(AdapterError(Box::new(Error::DbErr(err)))))?;
 
     Ok(true)
 }
+
 //  加载策略
 pub async fn load_policy(conn: &DatabaseConnection) -> Result<Vec<Model>> {
     let casbin_rule = Entity::find()
@@ -185,22 +183,22 @@ pub(crate) async fn load_filtered_policy<'a>(
                 .add(
                     Condition::all()
                         .add(Column::Ptype.like("p%"))
-                        .add(Column::V0.like(g_filter[0]))
-                        .add(Column::V1.like(g_filter[1]))
-                        .add(Column::V2.like(g_filter[2]))
-                        .add(Column::V3.like(g_filter[3]))
-                        .add(Column::V4.like(g_filter[4]))
-                        .add(Column::V5.like(g_filter[5])),
+                        .add(Column::V0.contains(g_filter[0]))
+                        .add(Column::V1.contains(g_filter[1]))
+                        .add(Column::V2.contains(g_filter[2]))
+                        .add(Column::V3.contains(g_filter[3]))
+                        .add(Column::V4.contains(g_filter[4]))
+                        .add(Column::V5.contains(g_filter[5])),
                 )
                 .add(
                     Condition::all()
                         .add(Column::Ptype.like("g%"))
-                        .add(Column::V0.like(p_filter[0]))
-                        .add(Column::V1.like(p_filter[1]))
-                        .add(Column::V2.like(p_filter[2]))
-                        .add(Column::V3.like(p_filter[3]))
-                        .add(Column::V4.like(p_filter[4]))
-                        .add(Column::V5.like(p_filter[5])),
+                        .add(Column::V0.contains(p_filter[0]))
+                        .add(Column::V1.contains(p_filter[1]))
+                        .add(Column::V2.contains(p_filter[2]))
+                        .add(Column::V3.contains(p_filter[3]))
+                        .add(Column::V4.contains(p_filter[4]))
+                        .add(Column::V5.contains(p_filter[5])),
                 ),
         )
         .all(conn)
